==> haskell-errors-2.3.0-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-1D1UHmXrwI7Bq9XxE6pmFN
key:                  errors-2.3.0-1D1UHmXrwI7Bq9XxE6pmFN
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  ceaad56071aebcf26dae6957eb548801
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-1D1UHmXrwI7Bq9XxE6pmFN
depends:
    base-4.17.2.1 exceptions-0.10.5 safe-0.3.21-KFRRgAe6GBS580TLl39TRp
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-JLgn8LP2yuX8UsXlcJZ1HO
key:                  errors-2.3.0-JLgn8LP2yuX8UsXlcJZ1HO
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  f03fbbac6fd026497208ef70ec9a0ba4
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-JLgn8LP2yuX8UsXlcJZ1HO
depends:
    base-4.17.2.1 exceptions-0.10.5 safe-0.3.21-4RbCGR2deY91o6dlI4zODz
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
